@@ -537,7 +537,12 @@ impl Trainer {
 fn load_config(config_path: Option<&Path>) -> Result<Config> {
 	if let Some(config_path) = config_path {
 		let config = std::fs::read_to_string(config_path)?;
-		let config = serde_json::from_str(&config)?;
+		let extension = config_path.extension().and_then(|s| s.to_str());
+		let config = match extension {
+			Some("json") => serde_json::from_str(&config)?,
+			Some("yaml") => serde_yaml::from_str(&config)?,
+			_ => bail!("the config path must have either .json or .yaml as its extension."),
+		};
 		Ok(config)
 	} else {
 		Ok(Config::default())
@@ -746,20 +751,20 @@ fn compute_hyperparameter_grid(
 			Task::Regression => grid::compute_regression_hyperparameter_grid(
 				grid,
 				target_column_index,
-				&train_column_stats,
+				train_column_stats,
 				config,
 			),
 			Task::BinaryClassification => grid::compute_binary_classification_hyperparameter_grid(
 				grid,
 				target_column_index,
-				&train_column_stats,
+				train_column_stats,
 				config,
 			),
 			Task::MulticlassClassification { .. } => {
 				grid::compute_multiclass_classification_hyperparameter_grid(
 					grid,
 					target_column_index,
-					&train_column_stats,
+					train_column_stats,
 					config,
 				)
 			}
@@ -767,18 +772,18 @@ fn compute_hyperparameter_grid(
 		.unwrap_or_else(|| match &task {
 			Task::Regression => grid::default_regression_hyperparameter_grid(
 				target_column_index,
-				&train_column_stats,
+				train_column_stats,
 				config,
 			),
 			Task::BinaryClassification => grid::default_binary_classification_hyperparameter_grid(
 				target_column_index,
-				&train_column_stats,
+				train_column_stats,
 				config,
 			),
 			Task::MulticlassClassification { .. } => {
 				grid::default_multiclass_classification_hyperparameter_grid(
 					target_column_index,
-					&train_column_stats,
+					train_column_stats,
 					config,
 				)
 			}
@@ -899,7 +904,7 @@ fn train_grid_item(
 	});
 	let duration = start.elapsed();
 	let comparison_metrics =
-		compute_comparison_metrics(&train_model_output, &table_comparison, &mut |progress| {
+		compute_comparison_metrics(&train_model_output, table_comparison, &mut |progress| {
 			handle_progress_event(ProgressEvent::Train(TrainProgressEvent {
 				grid_item_index,
 				grid_item_count,
@@ -1564,7 +1569,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_linear_regressor(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1580,7 +1585,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_tree_regressor(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1596,7 +1601,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_linear_binary_classifier(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1612,7 +1617,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_tree_binary_classifier(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1628,7 +1633,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_linear_multiclass_classifier(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1644,7 +1649,7 @@ fn compute_comparison_metrics(
 				..
 			} = &train_model_output;
 			let metrics = test::test_tree_multiclass_classifier(
-				&table_comparison,
+				table_comparison,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1768,7 +1773,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_linear_regressor(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1784,7 +1789,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_tree_regressor(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1800,7 +1805,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_linear_binary_classifier(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1816,7 +1821,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_tree_binary_classifier(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1832,7 +1837,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_linear_multiclass_classifier(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
@@ -1848,7 +1853,7 @@ fn test_model(
 				..
 			} = &train_model_output;
 			let test_metrics = test::test_tree_multiclass_classifier(
-				&table_test,
+				table_test,
 				*target_column_index,
 				feature_groups,
 				model,
